@@ -17,7 +17,12 @@ class EveGroupId(IntEnum):
     CONTROL_TOWER = 365
     ENGINEERING_COMPLEX = 1404
     FUEL_BLOCK = 1136
+    ICE_PRODUCT = 423
     REFINERY = 1406
+    PLANET = 7
+    STRUCTURE_CITADEL_SERVICE_MODULE = 1321
+    UNCOMMON_MOON_ASTEROIDS = 1921
+    QUANTUM_CORES = 4086
 
 
 class EveTypeId(IntEnum):
