@@ -13,8 +13,16 @@ logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 class Command(BaseCommand):
     help = "Preloads data required for this app from ESI"
 
+    def add_arguments(self, parser):
+        parser.add_argument(
+            "--noinput",
+            "--no-input",
+            action="store_true",
+            help="Do NOT prompt the user for input of any kind.",
+        )
+
     def handle(self, *args, **options):
-        call_command(
+        params = [
             "eveuniverse_load_types",
             __title__,
             "--category_id_with_dogma",
@@ -33,4 +41,7 @@ class Command(BaseCommand):
             EveTypeId.STRONTIUM.value,
             "--type_id",
             EveTypeId.TCU.value,
-        )
+        ]
+        if options["noinput"]:
+            params.append("--noinput")
+        call_command(*params)
